import pandas as pd
import numpy as np
import glob
import matplotlib.pyplot as plt
import matplotlib.colors as mcolors
import palettable

#load World Bank 2017 gdp_pc estimates
GDP=pd.read_csv("WB_GDP.csv")
wb_isolist=pd.unique(GDP.ISO)

table=pd.read_stata('T_econ.dta')

folder=''

T_seas_diff=[]
for i in range(len(wb_isolist)):
	iso=wb_isolist[i]
	file_name='T.5_' + iso + '_measure.npy'
	files=glob.glob(folder + file_name)
	print(iso)
	if len(files)==0:
		T_seas_diff.append(np.nan)
		print("nothing")
	else:
		print("got it")
		measure=np.load(folder + file_name)
		x=np.amax(measure[0,:,:,:],axis=2)-np.amin(measure[0,:,:,:],axis=2)
		T_seas_diff.append(np.nanmean(x[:,-8:]))	
	
GDP['T_diff']=T_seas_diff
GDP['ME']=-11.5+0.192*GDP['T_diff']

def label_point(x, y, val, ax,s):
    a = pd.concat({'x': x, 'y': y, 'val': val}, axis=1)
    for i, point in a.iterrows():
        ax.text(point['x'], point['y'], str(point['val']),fontsize=s)

def get_axis_limits(ax, scale):
    return ax.get_xlim()[0]*scale, ax.get_ylim()[1]*scale

#single
degree_sign= u'\N{DEGREE SIGN}'
C=degree_sign + 'C'
#individual panels
cm=1/2.54
fs=7
vmin=0
vmax=35
plt.close()
#size by population, colour by T_diff, discount countries with less than 1Million people
RdBu_8=palettable.colorbrewer.diverging.RdBu_8 
fig, axes = plt.subplots(1, 1,figsize=(8*cm,10*cm))
to_plot=GDP.loc[(~GDP.gdp_pc_usd.isnull()) & (~GDP.Pop.isnull()) & (~GDP.T_diff.isnull()) & (~GDP.ME.isnull()) & (GDP.Pop>1000000)]
scat=axes.scatter(x=to_plot['gdp_pc_usd'],y=to_plot['ME'],s=to_plot.Pop*0.00000015,c=to_plot['T_diff'],cmap=RdBu_8.mpl_colormap,vmin=vmin,vmax=vmax)
axes.set_ylim([-11.5,-3])
axes.set_yticks([-10,-8,-6,-4])
axes.set_xscale('log')
axes.set_xlabel('Country GDP per capita (USD of 2017)',fontsize=fs)
axes.set_ylabel('Marginal change in growth rate (% points)',fontsize=fs)
axes.tick_params(labelsize=fs)
cb=fig.colorbar(scat,ax=axes,orientation='horizontal',fraction=0.046, pad=0.13)
cb.set_label('Seasonal temperature difference',fontsize=fs)
cb.set_ticks([0,10,20,30])
cb.set_ticklabels(['0' + C,'10' + C,'20' + C,'30'+ C])
cb.ax.tick_params(labelsize=fs)
label_point(to_plot.gdp_pc_usd,to_plot.ME,to_plot.ISO,axes,fs-3)
plt.savefig('Fig_3.pdf',dpi=600,bbox_inches = 'tight',pad_inches = 0.05)
plt.close()

#double column
fig, axes = plt.subplots(1, 1,figsize=(18*cm,13*cm))
to_plot=GDP.loc[(~GDP.gdp_pc_usd.isnull()) & (~GDP.Pop.isnull()) & (~GDP.T_diff.isnull()) & (~GDP.ME.isnull()) & (GDP.Pop>1000000)]
scat=axes.scatter(x=to_plot['gdp_pc_usd'],y=to_plot['ME'],s=to_plot.Pop*0.0000003,c=to_plot['T_diff'],cmap=RdBu_8.mpl_colormap,vmin=vmin,vmax=vmax)
axes.set_ylim([-11.5,-3])
axes.set_yticks([-10,-8,-6,-4])
axes.set_xscale('log')
axes.set_xlabel('Country GDP per capita (USD of 2017)',fontsize=fs)
axes.set_ylabel('Marginal change in growth rate (% points)',fontsize=fs)
axes.tick_params(labelsize=fs)
cb=fig.colorbar(scat,ax=axes,orientation='horizontal',fraction=0.046, pad=0.12)
cb.set_label('Seasonal temperature difference',fontsize=fs)
cb.set_ticks([0,10,20,30])
cb.set_ticklabels(['0' + C,'10' + C,'20' + C,'30'+ C])
cb.ax.tick_params(labelsize=fs)
label_point(to_plot.gdp_pc_usd,to_plot.ME,to_plot.ISO,axes,fs)
plt.savefig('Fig_3_double.pdf',dpi=600,bbox_inches = 'tight',pad_inches = 0.05)
plt.close()


